Big changes, seems that 1.2.0 wasn't commited, here is 1.3.0, Daniel
diff --git a/include/libxml/parser.h b/include/libxml/parser.h
index aaab58c..0b8d22f 100644
--- a/include/libxml/parser.h
+++ b/include/libxml/parser.h
@@ -10,6 +10,7 @@
 #define __XML_PARSER_H__
 
 #include "tree.h"
+#include "xmlIO.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -22,6 +23,9 @@
 
 typedef void (* xmlParserInputDeallocate)(CHAR *);
 typedef struct xmlParserInput {
+    /* Input buffer */
+    xmlParserInputBufferPtr buf;      /* UTF-8 encoded buffer */
+
     const char *filename;             /* The file analyzed, if any */
     const CHAR *base;                 /* Base of the array to parse */
     const CHAR *cur;                  /* Current char being parsed */
@@ -169,8 +173,10 @@
 
 /*
  * Global variables: just the SAX interface tables we are looking for full
  *      reentrancy of the code !
  */
+extern const char *xmlParserVersion;
+
 extern xmlSAXLocator xmlDefaultSAXLocator;
 extern xmlSAXHandler xmlDefaultSAXHandler;
@@ -169,8 +173,10 @@
 /*
  * Global variables: just the SAX interface tables we are looking for full
- *      reentrancy of the code !
+ *      reentrancy of the code and version infos.
  */